/// ISO-4217 dataset
///
/// Describes currencies: their number, code and digits
///
/// {@category Datasets}
/// {@subCategory Currency}
library iso4217_dataset;

const List<Map<String, dynamic>> Iso4217 = [
  {'code': 'AED', 'number': 784, 'digits': 2},
  {'code': 'AFN', 'number': 971, 'digits': 2},
  {'code': 'ALL', 'number': 8, 'digits': 2},
  {'code': 'AMD', 'number': 51, 'digits': 2},
  {'code': 'ANG', 'number': 532, 'digits': 2},
  {'code': 'AOA', 'number': 973, 'digits': 2},
  {'code': 'ARS', 'number': 32, 'digits': 2},
  {'code': 'AUD', 'number': 36, 'digits': 2},
  {'code': 'AWG', 'number': 533, 'digits': 2},
  {'code': 'AZN', 'number': 944, 'digits': 2},
  {'code': 'BAM', 'number': 977, 'digits': 2},
  {'code': 'BBD', 'number': 52, 'digits': 2},
  {'code': 'BDT', 'number': 50, 'digits': 2},
  {'code': 'BGN', 'number': 975, 'digits': 2},
  {'code': 'BHD', 'number': 48, 'digits': 3},
  {'code': 'BIF', 'number': 108, 'digits': 0},
  {'code': 'BMD', 'number': 60, 'digits': 2},
  {'code': 'BND', 'number': 96, 'digits': 2},
  {'code': 'BOB', 'number': 68, 'digits': 2},
  {'code': 'BOV', 'number': 984, 'digits': 2},
  {'code': 'BRL', 'number': 986, 'digits': 2},
  {'code': 'BSD', 'number': 44, 'digits': 2},
  {'code': 'BTN', 'number': 64, 'digits': 2},
  {'code': 'BWP', 'number': 72, 'digits': 2},
  {'code': 'BYN', 'number': 933, 'digits': 2},
  {'code': 'BZD', 'number': 84, 'digits': 2},
  {'code': 'CAD', 'number': 124, 'digits': 2},
  {'code': 'CDF', 'number': 976, 'digits': 2},
  {'code': 'CHE', 'number': 947, 'digits': 2},
  {'code': 'CHF', 'number': 756, 'digits': 2},
  {'code': 'CHW', 'number': 948, 'digits': 2},
  {'code': 'CLF', 'number': 990, 'digits': 4},
  {'code': 'CLP', 'number': 152, 'digits': 0},
  {'code': 'CNY', 'number': 156, 'digits': 2},
  {'code': 'COP', 'number': 170, 'digits': 2},
  {'code': 'COU', 'number': 970, 'digits': 2},
  {'code': 'CRC', 'number': 188, 'digits': 2},
  {'code': 'CUC', 'number': 931, 'digits': 2},
  {'code': 'CUP', 'number': 192, 'digits': 2},
  {'code': 'CVE', 'number': 132, 'digits': 2},
  {'code': 'CZK', 'number': 203, 'digits': 2},
  {'code': 'DJF', 'number': 262, 'digits': 0},
  {'code': 'DKK', 'number': 208, 'digits': 2},
  {'code': 'DOP', 'number': 214, 'digits': 2},
  {'code': 'DZD', 'number': 12, 'digits': 2},
  {'code': 'EGP', 'number': 818, 'digits': 2},
  {'code': 'ERN', 'number': 232, 'digits': 2},
  {'code': 'ETB', 'number': 230, 'digits': 2},
  {'code': 'EUR', 'number': 978, 'digits': 2},
  {'code': 'FJD', 'number': 242, 'digits': 2},
  {'code': 'FKP', 'number': 238, 'digits': 2},
  {'code': 'GBP', 'number': 826, 'digits': 2},
  {'code': 'GEL', 'number': 981, 'digits': 2},
  {'code': 'GHS', 'number': 936, 'digits': 2},
  {'code': 'GIP', 'number': 292, 'digits': 2},
  {'code': 'GMD', 'number': 270, 'digits': 2},
  {'code': 'GNF', 'number': 324, 'digits': 0},
  {'code': 'GTQ', 'number': 320, 'digits': 2},
  {'code': 'GYD', 'number': 328, 'digits': 2},
  {'code': 'HKD', 'number': 344, 'digits': 2},
  {'code': 'HNL', 'number': 340, 'digits': 2},
  {'code': 'HRK', 'number': 191, 'digits': 2},
  {'code': 'HTG', 'number': 332, 'digits': 2},
  {'code': 'HUF', 'number': 348, 'digits': 2},
  {'code': 'IDR', 'number': 360, 'digits': 2},
  {'code': 'ILS', 'number': 376, 'digits': 2},
  {'code': 'INR', 'number': 356, 'digits': 2},
  {'code': 'IQD', 'number': 368, 'digits': 3},
  {'code': 'IRR', 'number': 364, 'digits': 2},
  {'code': 'ISK', 'number': 352, 'digits': 0},
  {'code': 'JMD', 'number': 388, 'digits': 2},
  {'code': 'JOD', 'number': 400, 'digits': 3},
  {'code': 'JPY', 'number': 392, 'digits': 0},
  {'code': 'KES', 'number': 404, 'digits': 2},
  {'code': 'KGS', 'number': 417, 'digits': 2},
  {'code': 'KHR', 'number': 116, 'digits': 2},
  {'code': 'KMF', 'number': 174, 'digits': 0},
  {'code': 'KPW', 'number': 408, 'digits': 2},
  {'code': 'KRW', 'number': 410, 'digits': 0},
  {'code': 'KWD', 'number': 414, 'digits': 3},
  {'code': 'KYD', 'number': 136, 'digits': 2},
  {'code': 'KZT', 'number': 398, 'digits': 2},
  {'code': 'LAK', 'number': 418, 'digits': 2},
  {'code': 'LBP', 'number': 422, 'digits': 2},
  {'code': 'LKR', 'number': 144, 'digits': 2},
  {'code': 'LRD', 'number': 430, 'digits': 2},
  {'code': 'LSL', 'number': 426, 'digits': 2},
  {'code': 'LYD', 'number': 434, 'digits': 3},
  {'code': 'MAD', 'number': 504, 'digits': 2},
  {'code': 'MDL', 'number': 498, 'digits': 2},
  {'code': 'MGA', 'number': 969, 'digits': 2},
  {'code': 'MKD', 'number': 807, 'digits': 2},
  {'code': 'MMK', 'number': 104, 'digits': 2},
  {'code': 'MNT', 'number': 496, 'digits': 2},
  {'code': 'MOP', 'number': 446, 'digits': 2},
  {'code': 'MRU', 'number': 929, 'digits': 2},
  {'code': 'MUR', 'number': 480, 'digits': 2},
  {'code': 'MVR', 'number': 462, 'digits': 2},
  {'code': 'MWK', 'number': 454, 'digits': 2},
  {'code': 'MXN', 'number': 484, 'digits': 2},
  {'code': 'MXV', 'number': 979, 'digits': 2},
  {'code': 'MYR', 'number': 458, 'digits': 2},
  {'code': 'MZN', 'number': 943, 'digits': 2},
  {'code': 'NAD', 'number': 516, 'digits': 2},
  {'code': 'NGN', 'number': 566, 'digits': 2},
  {'code': 'NIO', 'number': 558, 'digits': 2},
  {'code': 'NOK', 'number': 578, 'digits': 2},
  {'code': 'NPR', 'number': 524, 'digits': 2},
  {'code': 'NZD', 'number': 554, 'digits': 2},
  {'code': 'OMR', 'number': 512, 'digits': 3},
  {'code': 'PAB', 'number': 590, 'digits': 2},
  {'code': 'PEN', 'number': 604, 'digits': 2},
  {'code': 'PGK', 'number': 598, 'digits': 2},
  {'code': 'PHP', 'number': 608, 'digits': 2},
  {'code': 'PKR', 'number': 586, 'digits': 2},
  {'code': 'PLN', 'number': 985, 'digits': 2},
  {'code': 'PYG', 'number': 600, 'digits': 0},
  {'code': 'QAR', 'number': 634, 'digits': 2},
  {'code': 'RON', 'number': 946, 'digits': 2},
  {'code': 'RSD', 'number': 941, 'digits': 2},
  {'code': 'RUB', 'number': 643, 'digits': 2},
  {'code': 'RWF', 'number': 646, 'digits': 0},
  {'code': 'SAR', 'number': 682, 'digits': 2},
  {'code': 'SBD', 'number': 90, 'digits': 2},
  {'code': 'SCR', 'number': 690, 'digits': 2},
  {'code': 'SDG', 'number': 938, 'digits': 2},
  {'code': 'SEK', 'number': 752, 'digits': 2},
  {'code': 'SGD', 'number': 702, 'digits': 2},
  {'code': 'SHP', 'number': 654, 'digits': 2},
  {'code': 'SLL', 'number': 694, 'digits': 2},
  {'code': 'SOS', 'number': 706, 'digits': 2},
  {'code': 'SRD', 'number': 968, 'digits': 2},
  {'code': 'SSP', 'number': 728, 'digits': 2},
  {'code': 'STN', 'number': 930, 'digits': 2},
  {'code': 'SVC', 'number': 222, 'digits': 2},
  {'code': 'SYP', 'number': 760, 'digits': 2},
  {'code': 'SZL', 'number': 748, 'digits': 2},
  {'code': 'THB', 'number': 764, 'digits': 2},
  {'code': 'TJS', 'number': 972, 'digits': 2},
  {'code': 'TMT', 'number': 934, 'digits': 2},
  {'code': 'TND', 'number': 788, 'digits': 3},
  {'code': 'TOP', 'number': 776, 'digits': 2},
  {'code': 'TRY', 'number': 949, 'digits': 2},
  {'code': 'TTD', 'number': 780, 'digits': 2},
  {'code': 'TWD', 'number': 901, 'digits': 2},
  {'code': 'TZS', 'number': 834, 'digits': 2},
  {'code': 'UAH', 'number': 980, 'digits': 2},
  {'code': 'UGX', 'number': 800, 'digits': 0},
  {'code': 'USD', 'number': 840, 'digits': 2},
  {'code': 'USN', 'number': 997, 'digits': 2},
  {'code': 'UYI', 'number': 940, 'digits': 0},
  {'code': 'UYU', 'number': 858, 'digits': 2},
  {'code': 'UYW', 'number': 927, 'digits': 4},
  {'code': 'UZS', 'number': 860, 'digits': 2},
  {'code': 'VES', 'number': 928, 'digits': 2},
  {'code': 'VND', 'number': 704, 'digits': 0},
  {'code': 'VUV', 'number': 548, 'digits': 0},
  {'code': 'WST', 'number': 882, 'digits': 2},
  {'code': 'XAF', 'number': 950, 'digits': 0},
  {'code': 'XAG', 'number': 961, 'digits': 0},
  {'code': 'XAU', 'number': 959, 'digits': 0},
  {'code': 'XBA', 'number': 955, 'digits': 0},
  {'code': 'XBB', 'number': 956, 'digits': 0},
  {'code': 'XBC', 'number': 957, 'digits': 0},
  {'code': 'XBD', 'number': 958, 'digits': 0},
  {'code': 'XCD', 'number': 951, 'digits': 2},
  {'code': 'XDR', 'number': 960, 'digits': 0},
  {'code': 'XOF', 'number': 952, 'digits': 0},
  {'code': 'XPD', 'number': 964, 'digits': 0},
  {'code': 'XPF', 'number': 953, 'digits': 0},
  {'code': 'XPT', 'number': 962, 'digits': 0},
  {'code': 'XSU', 'number': 994, 'digits': 0},
  {'code': 'XTS', 'number': 963, 'digits': 0},
  {'code': 'XUA', 'number': 965, 'digits': 0},
  {'code': 'XXX', 'number': 999, 'digits': 0},
  {'code': 'YER', 'number': 886, 'digits': 2},
  {'code': 'ZAR', 'number': 710, 'digits': 2},
  {'code': 'ZMW', 'number': 967, 'digits': 2},
  {'code': 'ZWL', 'number': 932, 'digits': 2}
];
